@@ -475,7 +475,7 @@ def fill_date_gaps(df: pl.DataFrame, group_by_col: t.Union[str, t.List[str]] = "
 
     return full
 
-def check_min_max_dates(ranges: pl.DataFrame, cols_to_check: t.Union[str, t.List[str]], frequency: str = "1d") -> None:
+def check_min_max_dates(ranges: pl.DataFrame, cols_to_check: t.Union[str, t.List[str]], frequency: str = "daily") -> None:
 
     """
     Checks if the values in cols_to_check are valid for the given frequency. It checks:
